@@ -1,10 +1,9 @@
 use crate::authentication::Authentication;
+use crate::error::Error as ImageVaultError;
 use async_trait::async_trait;
 use std::time::{Duration, Instant};
 use url::Url;
 
-type BoxedError = Box<dyn std::error::Error>;
-
 #[derive(Default, Clone)]
 pub struct DummyAuth {
     auth_value: Option<String>,
@@ -29,7 +28,7 @@ impl Authentication for DummyAuth {
         _client_secret: &str,
         _base_url: &Url,
         _reqwest_client: &reqwest::Client,
-    ) -> Result<String, BoxedError> {
+    ) -> Result<String, ImageVaultError> {
         if let Some(auth_value) = &self.auth_value {
             // We have a value - is it valid still
             if let Some(validity) = self.valid_until {
