@@ -7,6 +7,7 @@ pub use client_credentials::ClientCredentialsAuthentication;
 pub use pin_code::PinCodeAuthentication;
 use url::Url;
 mod client_credentials;
+use crate::error::Error as ImageVaultError;
 #[cfg(test)]
 mod dummy_authentication;
 mod pin_code;
@@ -33,5 +34,5 @@ pub trait Authentication {
         client_secret: &str,
         base_url: &Url,
         reqwest_client: &reqwest::Client,
-    ) -> Result<String, Box<dyn std::error::Error>>;
+    ) -> Result<String, ImageVaultError>;
 }
