@@ -1,5 +1,5 @@
-use crate::{authentication::Authentication, data::InfoResult, error::Error, Client};
-type BoxedError = Box<dyn std::error::Error>;
+use crate::{authentication::Authentication, data::InfoResult, Client};
+use crate::error::Error as ImageVaultError;
 
 const INFO_ENDPOINT: &'static str = "/apiv2/assets/info";
 /// Calls the `assets/info` endpoint.
@@ -19,7 +19,7 @@ const INFO_ENDPOINT: &'static str = "/apiv2/assets/info";
 ///     authentication::ClientCredentialsAuthentication
 /// };
 ///
-/// # async fn test() -> Result<(), Box<dyn std::error::Error>> {
+/// # async fn test() -> Result<(), imagevault::error::Error> {
 /// let authentication = ClientCredentialsAuthentication::default();
 /// let client = Client::new(
 ///     "identity",
@@ -32,11 +32,11 @@ const INFO_ENDPOINT: &'static str = "/apiv2/assets/info";
 /// # Ok(())
 /// # }
 /// ```
-pub async fn info<T: Authentication + Sync>(client: &Client<T>) -> Result<InfoResult, BoxedError> {
+pub async fn info<T: Authentication + Sync>(client: &Client<T>) -> Result<InfoResult, ImageVaultError> {
     let auth_unwrapped = client
         .authentication
         .as_ref()
-        .ok_or_else(|| Error::AuthenticationMissing)?;
+        .ok_or_else(|| ImageVaultError::AuthenticationMissing)?;
     
     let auth_header = auth_unwrapped
         .lock()
@@ -57,7 +57,7 @@ pub async fn info<T: Authentication + Sync>(client: &Client<T>) -> Result<InfoRe
         .send()
         .await?;
     if let Err(err) = response.error_for_status_ref() {
-        return Err(Box::new(err));
+        return Err(err.into());
     } else {
         let result = response.json::<InfoResult>().await?;
         return Ok(result);
@@ -106,7 +106,7 @@ mod tests {
             let info_result = info(&client).await;
             assert!(info_result.is_err());
             let error_text = info_result.unwrap_err().to_string();
-            assert!(error_text == Error::AuthenticationMissing.to_string());
+            assert!(error_text == ImageVaultError::AuthenticationMissing.to_string());
         });
     }
 }
