@@ -1,8 +1,6 @@
-use crate::{authentication::Authentication, data::AssetsSearchResult, error::Error, Client};
+use crate::{authentication::Authentication, data::AssetsSearchResult, Client, error::Error as ImageVaultError};
 use serde::Serialize;
 
-type BoxedError = Box<dyn std::error::Error>;
-
 const SEARCH_ENDPOINT: &'static str = "apiv2/assets";
 
 /// A builder for the `assets/` search endpoint
@@ -135,7 +133,7 @@ impl SearchQuery {
 ///     authentication::ClientCredentialsAuthentication
 /// };
 ///
-/// # async fn test() -> Result<(), Box<dyn std::error::Error>> {
+/// # async fn test() -> Result<(), imagevault::error::Error> {
 /// let authentication = ClientCredentialsAuthentication::default();
 /// let client = Client::new(
 ///     "identity",
@@ -155,11 +153,11 @@ impl SearchQuery {
 pub async fn search<T: Authentication + Sync>(
     client: &Client<T>,
     search_query: &SearchQuery,
-) -> Result<AssetsSearchResult, BoxedError> {
+) -> Result<AssetsSearchResult, ImageVaultError> {
     let auth_unwrapped = client
         .authentication
         .as_ref()
-        .ok_or_else(|| Error::AuthenticationMissing)?;
+        .ok_or_else(|| ImageVaultError::AuthenticationMissing)?;
     let auth_header = auth_unwrapped
         .lock()
         .await
@@ -180,7 +178,7 @@ pub async fn search<T: Authentication + Sync>(
         .send()
         .await?;
     if let Err(err) = response.error_for_status_ref() {
-        return Err(Box::new(err));
+        return Err(err.into());
     } else {
         let result = response.json::<AssetsSearchResult>().await?;
         return Ok(result);
