@@ -1,5 +1,4 @@
-use crate::{authentication::Authentication, data::VersionResult, Client};
-type BoxedError = Box<dyn std::error::Error>;
+use crate::{authentication::Authentication, data::VersionResult, Client, error::Error as ImageVaultError};
 
 const VERSION_ENDPOINT: &'static str = "/apiv2/info/version";
 
@@ -17,7 +16,7 @@ const VERSION_ENDPOINT: &'static str = "/apiv2/info/version";
 ///     authentication::ClientCredentialsAuthentication
 /// };
 ///
-/// # async fn test() -> Result<(), Box<dyn std::error::Error>> {
+/// # async fn test() -> Result<(), imagevault::error::Error> {
 /// // Authentication is optional for this endpoint,
 /// // but is most likely needed for further API calls.
 /// let authentication = ClientCredentialsAuthentication::default();
@@ -32,12 +31,12 @@ const VERSION_ENDPOINT: &'static str = "/apiv2/info/version";
 /// # Ok(())
 /// # }
 /// ```
-pub async fn version<T: Authentication + Sync>(client: &Client<T>) -> Result<VersionResult, BoxedError> {
+pub async fn version<T: Authentication + Sync>(client: &Client<T>) -> Result<VersionResult, ImageVaultError> {
     let version_url = client.base_url.join(VERSION_ENDPOINT)?;
 
     let response = client.reqwest_client.get(version_url).send().await?;
     if let Err(err) = response.error_for_status_ref() {
-        return Err(Box::new(err));
+        return Err(err.into());
     } else {
         let result = response.json::<VersionResult>().await?;
         return Ok(result);
