@@ -1,12 +1,11 @@
 use crate::authentication::Authentication;
 use crate::data::MediaItem;
-use crate::error::Error;
+use crate::error::Error as ImageVaultError;
 use crate::Client;
 use serde::Serialize;
 use std::fs::metadata;
 use std::path::Path;
 
-type BoxedError = Box<dyn std::error::Error>;
 const STORE_CONTENT_ENDPOINT: &'static str = "apiv2/mediacontentservice/storecontentinvault";
 
 /// Calls `mediacontentservice/storecontentinvault`.
@@ -33,7 +32,7 @@ const STORE_CONTENT_ENDPOINT: &'static str = "apiv2/mediacontentservice/storecon
 ///     authentication::ClientCredentialsAuthentication
 /// };
 ///
-/// # async fn test() -> Result<(), Box<dyn std::error::Error>> {
+/// # async fn test() -> Result<(), imagevault::error::Error> {
 /// let authentication = ClientCredentialsAuthentication::default();
 /// let client = Client::new(
 ///     "identity",
@@ -66,7 +65,7 @@ pub async fn store_content_in_vault_from_path<T: Authentication + Sync>(
     path: &Path,
     upload_file_id: &str,
     vault_id: u64,
-) -> Result<MediaItem, BoxedError> {
+) -> Result<MediaItem, ImageVaultError> {
     let _md = metadata(path)?;
     let os_file_name = path.file_name().ok_or(std::io::Error::new(
         std::io::ErrorKind::InvalidData,
@@ -114,7 +113,7 @@ pub async fn store_content_in_vault_from_path<T: Authentication + Sync>(
 ///     authentication::ClientCredentialsAuthentication
 /// };
 ///
-/// # async fn test() -> Result<(), Box<dyn std::error::Error>> {
+/// # async fn test() -> Result<(), imagevault::error::Error> {
 /// let authentication = ClientCredentialsAuthentication::default();
 /// let client = Client::new(
 ///     "identity",
@@ -149,12 +148,12 @@ pub async fn store_content_in_vault<T: Authentication + Sync>(
     content_type: &str,
     upload_file_id: &str,
     vault_id: u64,
-) -> Result<MediaItem, BoxedError> {
+) -> Result<MediaItem, ImageVaultError> {
     let full_url = client.base_url.join(STORE_CONTENT_ENDPOINT)?;
     let auth_unwrapped = client
         .authentication
         .as_ref()
-        .ok_or_else(|| Error::AuthenticationMissing)?;
+        .ok_or_else(|| ImageVaultError::AuthenticationMissing)?;
     let auth_header = auth_unwrapped
         .lock()
         .await
@@ -180,7 +179,7 @@ pub async fn store_content_in_vault<T: Authentication + Sync>(
         .send()
         .await?;
     if let Err(err) = response.error_for_status_ref() {
-        return Err(Box::new(err));
+        return Err(err.into());
     } else {
         return Ok(response.json::<MediaItem>().await?);
     }
